Crate access_token

Crate access_token 

LiveKit Token

Important: This is an internal crate which contains logic to generate new LiveKit tokens.

To use this logic in an end application, consume it via its reexport in the livekit-api crate.

Structs

AccessToken
Claims
SIPGrants
TokenVerifier
VideoGrants

Enums

AccessTokenError

Constants

DEFAULT_TTL