pub enum AudioMixing {
DefaultMixing,
DualChannelAgent,
DualChannelAlternate,
}Variants
DefaultMixing
All users are mixed together.
DualChannelAgent
Agent audio in the left channel, all other audio in the right channel.
DualChannelAlternate
Each new audio track alternates between left and right channels.