pub struct TransferSIPParticipantOptions {
pub play_dialtone: Option<bool>,
pub ringing_timeout: Option<Duration>,
pub headers: Option<HashMap<String, String>>,
pub timeout: Option<Duration>,
}Fields
play_dialtone: Option<bool>Optionally play a dialtone to the SIP participant as an audible indicator of being transferred.
ringing_timeout: Option<Duration>Max time for the transfer destination to answer the call.
headers: Option<HashMap<String, String>>SIP headers added to the REFER SIP request.
timeout: Option<Duration>Per-request timeout override. A transfer always dials (REFER) and blocks
until the destination answers, so this is raised, if needed, to stay above
ringing_timeout.